.. _examples:

Examples
========

Welcome to the AstroDynX examples! These guides will help you get started with orbital mechanics calculations using AstroDynX.

Some examples are available:

.. toctree::
   :maxdepth: 1

   prop_cowell

Planned Examples
----------------

The following examples are planned for future releases:

**Kepler Propagation**
   Analytical orbital propagation examples using Kepler's equation. Demonstrates the use of different formulations of Kepler's equation and
   their applications in different scenarios.

**Orbital Elements**
   Examples of working with orbital elements. Demonstrates the use of different orbital elements and their transformations.

**Event Detection**
   Examples of using event detection in orbital simulations. Demonstrates the use of different events and their applications in various
   scenarios.
